pub struct SignBlockEntity {
base: BlockEntityBase,
sign: SyncMutex<SignState>,
}Expand description
Sign block entity.
Stores text on both front and back sides of the sign.
Fields
base: BlockEntityBasesign: SyncMutex<SignState>Implementations
Sourceimpl SignBlockEntity
impl SignBlockEntity
Sourcepub fn new(level: Weak<World>, pos: BlockPos, state: BlockStateId) -> Self
pub fn new(level: Weak<World>, pos: BlockPos, state: BlockStateId) -> Self
Creates a new sign block entity.
Sourcepub fn new_hanging(
level: Weak<World>,
pos: BlockPos,
state: BlockStateId,
) -> Self
pub fn new_hanging( level: Weak<World>, pos: BlockPos, state: BlockStateId, ) -> Self
Creates a new hanging sign block entity.
Sourcepub fn with_type(
level: Weak<World>,
block_entity_type: BlockEntityTypeRef,
pos: BlockPos,
state: BlockStateId,
) -> Self
pub fn with_type( level: Weak<World>, block_entity_type: BlockEntityTypeRef, pos: BlockPos, state: BlockStateId, ) -> Self
Creates a sign block entity with a specific type.
Sourcepub fn get_player_who_may_edit(&self) -> Option<Uuid>
pub fn get_player_who_may_edit(&self) -> Option<Uuid>
Gets the UUID of the player currently allowed to edit this sign.
Sourcepub fn set_player_who_may_edit(&self, player: Option<Uuid>)
pub fn set_player_who_may_edit(&self, player: Option<Uuid>)
Sets the player allowed to edit this sign.
Sourcepub fn is_other_player_editing(&self, player_uuid: Uuid) -> bool
pub fn is_other_player_editing(&self, player_uuid: Uuid) -> bool
Checks if another player (not the given one) is currently editing this sign.